@@ -8,11 +8,13 @@
 #include "../richtextcomposer.h"
 #include "../richtextcomposercontroler.h"
 #include <KActionCollection>
+#include <QStandardPaths>
 #include <QTest>
 
 RichTextComposerControlerTest::RichTextComposerControlerTest(QObject *parent)
     : QObject(parent)
 {
+    QStandardPaths::setTestModeEnabled(true);
 }
 
 RichTextComposerControlerTest::~RichTextComposerControlerTest() = default;
@@ -22,13 +24,13 @@ void RichTextComposerControlerTest::shouldAlignLeft()
     KPIMTextEdit::RichTextComposer composer;
     auto actionCollection = new KActionCollection(&composer);
     composer.createActions(actionCollection);
-    KPIMTextEdit::RichTextComposerControler controler(&composer);
+    KPIMTextEdit::RichTextComposerControler controller(&composer);
     composer.show();
     QVERIFY(QTest::qWaitForWindowExposed(&composer));
-    controler.alignLeft();
-    // QVERIFY(controler.richTextComposer()->hasFocus());
-    QCOMPARE(controler.richTextComposer()->alignment(), Qt::AlignLeft);
-    QVERIFY(controler.richTextComposer()->acceptRichText());
+    controller.alignLeft();
+    // QVERIFY(controller.richTextComposer()->hasFocus());
+    QCOMPARE(controller.richTextComposer()->alignment(), Qt::AlignLeft);
+    QVERIFY(controller.richTextComposer()->acceptRichText());
 }
 
 void RichTextComposerControlerTest::shouldAlignRight()
@@ -36,13 +38,13 @@ void RichTextComposerControlerTest::shouldAlignRight()
     KPIMTextEdit::RichTextComposer composer;
     auto actionCollection = new KActionCollection(&composer);
     composer.createActions(actionCollection);
-    KPIMTextEdit::RichTextComposerControler controler(&composer);
+    KPIMTextEdit::RichTextComposerControler controller(&composer);
     composer.show();
     QVERIFY(QTest::qWaitForWindowExposed(&composer));
-    controler.alignRight();
-    QVERIFY(controler.richTextComposer()->hasFocus());
-    QCOMPARE(controler.richTextComposer()->alignment(), Qt::AlignRight);
-    QVERIFY(controler.richTextComposer()->acceptRichText());
+    controller.alignRight();
+    QVERIFY(controller.richTextComposer()->hasFocus());
+    QCOMPARE(controller.richTextComposer()->alignment(), Qt::AlignRight);
+    QVERIFY(controller.richTextComposer()->acceptRichText());
 }
 
 void RichTextComposerControlerTest::shouldAlignJustify()
@@ -50,13 +52,13 @@ void RichTextComposerControlerTest::shouldAlignJustify()
     KPIMTextEdit::RichTextComposer composer;
     auto actionCollection = new KActionCollection(&composer);
     composer.createActions(actionCollection);
-    KPIMTextEdit::RichTextComposerControler controler(&composer);
+    KPIMTextEdit::RichTextComposerControler controller(&composer);
     composer.show();
     QVERIFY(QTest::qWaitForWindowExposed(&composer));
-    controler.alignJustify();
-    // QVERIFY(controler.richTextComposer()->hasFocus());
-    QCOMPARE(controler.richTextComposer()->alignment(), Qt::AlignJustify);
-    QVERIFY(controler.richTextComposer()->acceptRichText());
+    controller.alignJustify();
+    // QVERIFY(controller.richTextComposer()->hasFocus());
+    QCOMPARE(controller.richTextComposer()->alignment(), Qt::AlignJustify);
+    QVERIFY(controller.richTextComposer()->acceptRichText());
 }
 
 void RichTextComposerControlerTest::shouldAlignCenter()
@@ -64,21 +66,21 @@ void RichTextComposerControlerTest::shouldAlignCenter()
     KPIMTextEdit::RichTextComposer composer;
     auto actionCollection = new KActionCollection(&composer);
     composer.createActions(actionCollection);
-    KPIMTextEdit::RichTextComposerControler controler(&composer);
+    KPIMTextEdit::RichTextComposerControler controller(&composer);
     composer.show();
     QVERIFY(QTest::qWaitForWindowExposed(&composer));
-    controler.alignCenter();
-    // QVERIFY(controler.richTextComposer()->hasFocus());
-    QCOMPARE(controler.richTextComposer()->alignment(), Qt::AlignHCenter);
-    QVERIFY(controler.richTextComposer()->acceptRichText());
+    controller.alignCenter();
+    // QVERIFY(controller.richTextComposer()->hasFocus());
+    QCOMPARE(controller.richTextComposer()->alignment(), Qt::AlignHCenter);
+    QVERIFY(controller.richTextComposer()->acceptRichText());
 }
 
 void RichTextComposerControlerTest::shouldHaveDefaultValue()
 {
     KPIMTextEdit::RichTextComposer composer;
-    KPIMTextEdit::RichTextComposerControler controler(&composer);
-    QVERIFY(!controler.painterActive());
-    QVERIFY(!controler.richTextComposer()->acceptRichText());
+    KPIMTextEdit::RichTextComposerControler controller(&composer);
+    QVERIFY(!controller.painterActive());
+    QVERIFY(!controller.richTextComposer()->acceptRichText());
 }
 
 void RichTextComposerControlerTest::shouldBoldText()
@@ -86,12 +88,12 @@ void RichTextComposerControlerTest::shouldBoldText()
     KPIMTextEdit::RichTextComposer composer;
     auto actionCollection = new KActionCollection(&composer);
     composer.createActions(actionCollection);
-    KPIMTextEdit::RichTextComposerControler controler(&composer);
+    KPIMTextEdit::RichTextComposerControler controller(&composer);
     composer.show();
     QVERIFY(QTest::qWaitForWindowExposed(&composer));
-    controler.setTextBold(true);
-    // QVERIFY(controler.richTextComposer()->hasFocus());
-    QVERIFY(controler.richTextComposer()->acceptRichText());
+    controller.setTextBold(true);
+    // QVERIFY(controller.richTextComposer()->hasFocus());
+    QVERIFY(controller.richTextComposer()->acceptRichText());
     // TODO text format.
 }
 
@@ -100,12 +102,12 @@ void RichTextComposerControlerTest::shouldItalicText()
     KPIMTextEdit::RichTextComposer composer;
     auto actionCollection = new KActionCollection(&composer);
     composer.createActions(actionCollection);
-    KPIMTextEdit::RichTextComposerControler controler(&composer);
+    KPIMTextEdit::RichTextComposerControler controller(&composer);
     composer.show();
     QVERIFY(QTest::qWaitForWindowExposed(&composer));
-    controler.setTextItalic(true);
-    // QVERIFY(controler.richTextComposer()->hasFocus());
-    QVERIFY(controler.richTextComposer()->acceptRichText());
+    controller.setTextItalic(true);
+    // QVERIFY(controller.richTextComposer()->hasFocus());
+    QVERIFY(controller.richTextComposer()->acceptRichText());
     // TODO text format.
 }
 
@@ -114,12 +116,12 @@ void RichTextComposerControlerTest::shouldTextUnderline()
     KPIMTextEdit::RichTextComposer composer;
     auto actionCollection = new KActionCollection(&composer);
     composer.createActions(actionCollection);
-    KPIMTextEdit::RichTextComposerControler controler(&composer);
+    KPIMTextEdit::RichTextComposerControler controller(&composer);
     composer.show();
     QVERIFY(QTest::qWaitForWindowExposed(&composer));
-    controler.setTextUnderline(true);
-    // QVERIFY(controler.richTextComposer()->hasFocus());
-    QVERIFY(controler.richTextComposer()->acceptRichText());
+    controller.setTextUnderline(true);
+    // QVERIFY(controller.richTextComposer()->hasFocus());
+    QVERIFY(controller.richTextComposer()->acceptRichText());
     // TODO text format.
 }
 
@@ -128,12 +130,12 @@ void RichTextComposerControlerTest::shouldTextStrikeOut()
     KPIMTextEdit::RichTextComposer composer;
     auto actionCollection = new KActionCollection(&composer);
     composer.createActions(actionCollection);
-    KPIMTextEdit::RichTextComposerControler controler(&composer);
+    KPIMTextEdit::RichTextComposerControler controller(&composer);
     composer.show();
     QVERIFY(QTest::qWaitForWindowExposed(&composer));
-    controler.setTextStrikeOut(true);
-    // QVERIFY(controler.richTextComposer()->hasFocus());
-    QVERIFY(controler.richTextComposer()->acceptRichText());
+    controller.setTextStrikeOut(true);
+    // QVERIFY(controller.richTextComposer()->hasFocus());
+    QVERIFY(controller.richTextComposer()->acceptRichText());
     // TODO text format.
 }
 
@@ -142,7 +144,7 @@ void RichTextComposerControlerTest::shouldFontFamily()
     KPIMTextEdit::RichTextComposer composer;
     auto actionCollection = new KActionCollection(&composer);
     composer.createActions(actionCollection);
-    KPIMTextEdit::RichTextComposerControler controler(&composer);
+    KPIMTextEdit::RichTextComposerControler controller(&composer);
     composer.show();
     QVERIFY(QTest::qWaitForWindowExposed(&composer));
     // TODO
@@ -153,7 +155,7 @@ void RichTextComposerControlerTest::shouldFontSize()
     KPIMTextEdit::RichTextComposer composer;
     auto actionCollection = new KActionCollection(&composer);
     composer.createActions(actionCollection);
-    KPIMTextEdit::RichTextComposerControler controler(&composer);
+    KPIMTextEdit::RichTextComposerControler controller(&composer);
     composer.show();
     QVERIFY(QTest::qWaitForWindowExposed(&composer));
     // TODO
@@ -164,7 +166,7 @@ void RichTextComposerControlerTest::shouldFont()
     KPIMTextEdit::RichTextComposer composer;
     auto actionCollection = new KActionCollection(&composer);
     composer.createActions(actionCollection);
-    KPIMTextEdit::RichTextComposerControler controler(&composer);
+    KPIMTextEdit::RichTextComposerControler controller(&composer);
     composer.show();
     QVERIFY(QTest::qWaitForWindowExposed(&composer));
     // TODO
@@ -175,12 +177,12 @@ void RichTextComposerControlerTest::shouldTextSuperScript()
     KPIMTextEdit::RichTextComposer composer;
     auto actionCollection = new KActionCollection(&composer);
     composer.createActions(actionCollection);
-    KPIMTextEdit::RichTextComposerControler controler(&composer);
+    KPIMTextEdit::RichTextComposerControler controller(&composer);
     composer.show();
     QVERIFY(QTest::qWaitForWindowExposed(&composer));
-    controler.setTextSuperScript(true);
-    QVERIFY(controler.richTextComposer()->hasFocus());
-    QVERIFY(controler.richTextComposer()->acceptRichText());
+    controller.setTextSuperScript(true);
+    QVERIFY(controller.richTextComposer()->hasFocus());
+    QVERIFY(controller.richTextComposer()->acceptRichText());
     // TODO
 }
 
@@ -189,12 +191,12 @@ void RichTextComposerControlerTest::shouldTextSubScript()
     KPIMTextEdit::RichTextComposer composer;
     auto actionCollection = new KActionCollection(&composer);
     composer.createActions(actionCollection);
-    KPIMTextEdit::RichTextComposerControler controler(&composer);
+    KPIMTextEdit::RichTextComposerControler controller(&composer);
     composer.show();
     QVERIFY(QTest::qWaitForWindowExposed(&composer));
-    controler.setTextSubScript(true);
-    QVERIFY(controler.richTextComposer()->hasFocus());
-    QVERIFY(controler.richTextComposer()->acceptRichText());
+    controller.setTextSubScript(true);
+    QVERIFY(controller.richTextComposer()->hasFocus());
+    QVERIFY(controller.richTextComposer()->acceptRichText());
 
     // TODO
 }
@@ -226,12 +228,12 @@ void RichTextComposerControlerTest::shouldRemoveQuote()
     KPIMTextEdit::RichTextComposer composer;
     auto actionCollection = new KActionCollection(&composer);
     composer.createActions(actionCollection);
-    KPIMTextEdit::RichTextComposerControler controler(&composer);
+    KPIMTextEdit::RichTextComposerControler controller(&composer);
     composer.show();
     QVERIFY(QTest::qWaitForWindowExposed(&composer));
 
     composer.setPlainText(input);
-    controler.slotRemoveQuotes();
+    controller.slotRemoveQuotes();
     QCOMPARE(composer.toPlainText(), output);
 }
 
@@ -256,12 +258,12 @@ void RichTextComposerControlerTest::shouldRemoveQuoteWithSpecificQuote()
     composer.setQuotePrefixName(quote);
     auto actionCollection = new KActionCollection(&composer);
     composer.createActions(actionCollection);
-    KPIMTextEdit::RichTextComposerControler controler(&composer);
+    KPIMTextEdit::RichTextComposerControler controller(&composer);
     composer.show();
     QVERIFY(QTest::qWaitForWindowExposed(&composer));
 
     composer.setPlainText(input);
-    controler.slotRemoveQuotes();
+    controller.slotRemoveQuotes();
     QCOMPARE(composer.toPlainText(), output);
 }
 
@@ -286,12 +288,12 @@ void RichTextComposerControlerTest::shouldAddQuote()
     //    composer.setQuotePrefixName(quote);
     //    KActionCollection *actionCollection = new KActionCollection(&composer);
     //    composer.createActions(actionCollection);
-    //    KPIMTextEdit::RichTextComposerControler controler(&composer);
+    //    KPIMTextEdit::RichTextComposerControler controller(&composer);
     //    composer.show();
     //    QVERIFY(QTest::qWaitForWindowExposed(&composer));
 
     //    composer.setPlainText(input);
-    //    controler.slotAddQuotes();
+    //    controller.slotAddQuotes();
     //    QCOMPARE(composer.toPlainText(), QString(output + QChar::ParagraphSeparator));
 }
 
