@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2015-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -12,8 +12,6 @@ RichTextComposerImagesTest::RichTextComposerImagesTest(QObject *parent)
 {
 }
 
-RichTextComposerImagesTest::~RichTextComposerImagesTest()
-{
-}
+RichTextComposerImagesTest::~RichTextComposerImagesTest() = default;
 
 QTEST_MAIN(RichTextComposerImagesTest)
