@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2015-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -148,7 +148,7 @@ ImageWithNameList RichTextComposerImages::imagesWithName() const
         const QString name = imageFormat.name();
         if (!seenImageNames.contains(name)) {
             QVariant resourceData = d->composer->document()->resource(QTextDocument::ImageResource, QUrl(name));
-            QImage image = qvariant_cast<QImage>(resourceData);
+            auto image = qvariant_cast<QImage>(resourceData);
 
             ImageWithNamePtr newImage(new ImageWithName);
             newImage->image = image;
