@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2021-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -22,7 +22,7 @@ void EmoticonTextEditSelectorTest::shouldHaveDefaultValues()
     KPIMTextEdit::EmoticonTextEditSelector w;
     auto mainLayout = w.findChild<QVBoxLayout *>(QStringLiteral("mainLayout"));
     QVERIFY(mainLayout);
-    QCOMPARE(mainLayout->contentsMargins(), {});
+    QCOMPARE(mainLayout->contentsMargins(), QMargins{});
 
     auto mUnicodeTab = w.findChild<KPIMTextEdit::EmoticonUnicodeTab *>(QStringLiteral("mUnicodeTab"));
     QVERIFY(mUnicodeTab);
