@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2021-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -16,9 +16,7 @@ EmoticonRecentListView::EmoticonRecentListView(QWidget *parent)
     setContextMenuPolicy(Qt::DefaultContextMenu);
 }
 
-EmoticonRecentListView::~EmoticonRecentListView()
-{
-}
+EmoticonRecentListView::~EmoticonRecentListView() = default;
 
 void EmoticonRecentListView::contextMenuEvent(QContextMenuEvent *event)
 {
