@@ -1,13 +1,11 @@
 /*
-   SPDX-FileCopyrightText: 2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2021-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "emoticonrecentusedfilterproxymodel.h"
 #include "emoticonunicodemodel.h"
-#include <KConfig>
-#include <KConfigGroup>
 #include <KSharedConfig>
 
 using namespace KPIMTextEdit;
@@ -17,10 +15,7 @@ EmoticonRecentUsedFilterProxyModel::EmoticonRecentUsedFilterProxyModel(QObject *
     sort(0);
 }
 
-EmoticonRecentUsedFilterProxyModel::~EmoticonRecentUsedFilterProxyModel()
-{
-}
-
+EmoticonRecentUsedFilterProxyModel::~EmoticonRecentUsedFilterProxyModel() = default;
 
 QStringList EmoticonRecentUsedFilterProxyModel::usedIdentifier() const
 {
