@@ -1,20 +1,17 @@
 /*
-   SPDX-FileCopyrightText: 2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2021-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "emoticonunicodemodel.h"
-#include <KLocalizedString>
 using namespace KPIMTextEdit;
 EmoticonUnicodeModel::EmoticonUnicodeModel(QObject *parent)
     : QAbstractListModel(parent)
 {
 }
 
-EmoticonUnicodeModel::~EmoticonUnicodeModel()
-{
-}
+EmoticonUnicodeModel::~EmoticonUnicodeModel() = default;
 
 int EmoticonUnicodeModel::rowCount(const QModelIndex &parent) const
 {
