@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -8,7 +8,6 @@
 
 #include "kpimtextedit_export.h"
 #include <QRegularExpression>
-#include <QTextDocument>
 #include <QWidget>
 namespace KPIMTextEdit
 {
@@ -23,6 +22,14 @@ class KPIMTEXTEDIT_EXPORT TextEditFindBarBase : public QWidget
     Q_OBJECT
 
 public:
+    enum FindFlag {
+        FindBackward = 0x00001,
+        FindCaseSensitively = 0x00002,
+        FindWholeWords = 0x00004,
+        FindRespectDiacritics = 0x00008,
+    };
+    Q_DECLARE_FLAGS(FindFlags, FindFlag)
+
     explicit TextEditFindBarBase(QWidget *parent = nullptr);
     ~TextEditFindBarBase() override;
 
@@ -42,8 +49,8 @@ Q_SIGNALS:
 protected:
     Q_REQUIRED_RESULT virtual bool viewIsReadOnly() const = 0;
     Q_REQUIRED_RESULT virtual bool documentIsEmpty() const = 0;
-    Q_REQUIRED_RESULT virtual bool searchInDocument(const QString &text, QTextDocument::FindFlags searchOptions) = 0;
-    Q_REQUIRED_RESULT virtual bool searchInDocument(const QRegularExpression &regExp, QTextDocument::FindFlags searchOptions) = 0;
+    virtual bool searchInDocument(const QString &text, TextEditFindBarBase::FindFlags searchOptions) = 0;
+    virtual bool searchInDocument(const QRegularExpression &regExp, TextEditFindBarBase::FindFlags searchOptions) = 0;
     virtual void autoSearchMoveCursor() = 0;
 
     bool event(QEvent *e) override;
@@ -69,9 +76,8 @@ private Q_SLOTS:
 protected:
     QString mLastSearchStr;
     QRegularExpression mLastSearchRegExp;
-    TextFindWidget *mFindWidget = nullptr;
-    TextReplaceWidget *mReplaceWidget = nullptr;
+    TextFindWidget *const mFindWidget;
+    TextReplaceWidget *const mReplaceWidget;
     bool mHideWhenClose = true;
 };
 }
-
