@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2012-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2012-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -8,7 +8,6 @@
 #include "texteditor/commonwidget/findutils.h"
 #include "texteditor/commonwidget/textfindreplacewidget.h"
 
-#include <KColorScheme>
 #include <KLocalizedString>
 
 #include <QLineEdit>
@@ -16,7 +15,6 @@
 #include <QRegularExpression>
 
 using namespace KPIMTextEdit;
-
 class KPIMTextEdit::PlainTextEditFindBarPrivate
 {
 public:
@@ -52,16 +50,21 @@ bool PlainTextEditFindBar::documentIsEmpty() const
     return d->mView->document()->isEmpty();
 }
 
-bool PlainTextEditFindBar::searchInDocument(const QString &text, QTextDocument::FindFlags searchOptions)
+bool PlainTextEditFindBar::searchInDocument(const QString &text, TextEditFindBarBase::FindFlags searchOptions)
 {
-    const bool found = d->mView->find(text, searchOptions);
+    bool found = false;
+    if (searchOptions & TextEditFindBarBase::FindRespectDiacritics) {
+        found = d->mView->find(text, FindUtils::convertTextEditFindFlags(searchOptions));
+    } else {
+        found = FindUtils::find(d->mView, text, FindUtils::convertTextEditFindFlags(searchOptions));
+    }
     mFindWidget->setFoundMatch(found);
     return found;
 }
 
-bool PlainTextEditFindBar::searchInDocument(const QRegularExpression &regExp, QTextDocument::FindFlags searchOptions)
+bool PlainTextEditFindBar::searchInDocument(const QRegularExpression &regExp, TextEditFindBarBase::FindFlags searchOptions)
 {
-    const bool found = d->mView->find(regExp, searchOptions);
+    const bool found = d->mView->find(regExp, FindUtils::convertTextEditFindFlags(searchOptions));
     mFindWidget->setFoundMatch(found);
     return found;
 }
@@ -75,18 +78,27 @@ void PlainTextEditFindBar::autoSearchMoveCursor()
 
 void PlainTextEditFindBar::slotReplaceText()
 {
+    const TextEditFindBarBase::FindFlags searchOptions = mFindWidget->searchOptions();
     if (d->mView->textCursor().hasSelection()) {
         if (mFindWidget->isRegularExpression()) {
-            if (d->mView->textCursor().selectedText().contains(mFindWidget->searchRegExp())) {
+            if (d->mView->textCursor().selectedText().contains(mFindWidget->searchRegularExpression())) {
                 d->mView->textCursor().insertText(mReplaceWidget->replaceLineEdit()->text());
                 // search next after replace text.
                 searchText(false, false);
             }
         } else {
-            if (d->mView->textCursor().selectedText() == mFindWidget->searchText()) {
-                d->mView->textCursor().insertText(mReplaceWidget->replaceLineEdit()->text());
-                // search next after replace text.
-                searchText(false, false);
+            if (searchOptions & TextEditFindBarBase::FindRespectDiacritics) {
+                if (FindUtils::normalize(d->mView->textCursor().selectedText()) == FindUtils::normalize(mFindWidget->searchText())) {
+                    d->mView->textCursor().insertText(mReplaceWidget->replaceLineEdit()->text());
+                    // search next after replace text.
+                    searchText(false, false);
+                } else {
+                    if (d->mView->textCursor().selectedText() == mFindWidget->searchText()) {
+                        d->mView->textCursor().insertText(mReplaceWidget->replaceLineEdit()->text());
+                        // search next after replace text.
+                        searchText(false, false);
+                    }
+                }
             }
         }
     } else {
@@ -96,6 +108,13 @@ void PlainTextEditFindBar::slotReplaceText()
 
 void PlainTextEditFindBar::slotReplaceAllText()
 {
-    const int count = FindUtils::replaceAll(d->mView->document(), mFindWidget, mReplaceWidget);
+    int count = 0;
+    const QString replaceStr{mReplaceWidget->replaceLineEdit()->text()};
+    const TextEditFindBarBase::FindFlags searchOptions{mFindWidget->searchOptions()};
+    if (mFindWidget->isRegularExpression()) {
+        count = FindUtils::replaceAll(d->mView->document(), mFindWidget->searchRegularExpression(), replaceStr, searchOptions);
+    } else {
+        count = FindUtils::replaceAll(d->mView, mFindWidget->searchText(), replaceStr, searchOptions);
+    }
     Q_EMIT displayMessageIndicator(i18np("%1 replacement made", "%1 replacements made", count));
 }
