@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2014-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2014-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -13,9 +13,7 @@ RichTextEditorTest::RichTextEditorTest(QObject *parent)
 {
 }
 
-RichTextEditorTest::~RichTextEditorTest()
-{
-}
+RichTextEditorTest::~RichTextEditorTest() = default;
 
 void RichTextEditorTest::shouldHaveDefaultValue()
 {
