@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -10,8 +10,9 @@
 
 #include <QTextCursor>
 #include <QVBoxLayout>
+#ifdef HAVE_TEXT_TO_SPEECH_SUPPORT
 #include <texttospeech/texttospeechwidget.h>
-
+#endif
 #include "slidecontainer.h"
 
 using namespace KPIMTextEdit;
@@ -19,13 +20,13 @@ using namespace KPIMTextEdit;
 class Q_DECL_HIDDEN KPIMTextEdit::RichTextEditorWidgetPrivate
 {
 public:
-    RichTextEditorWidgetPrivate()
-    {
-    }
+    RichTextEditorWidgetPrivate() = default;
 
     KPIMTextEdit::RichTextEditFindBar *mFindBar = nullptr;
     RichTextEditor *mEditor = nullptr;
+#ifdef HAVE_TEXT_TO_SPEECH_SUPPORT
     KPIMTextEdit::TextToSpeechWidget *mTextToSpeechWidget = nullptr;
+#endif
     KPIMTextEdit::SlideContainer *mSliderContainer = nullptr;
 };
 
@@ -99,14 +100,18 @@ void RichTextEditorWidget::init(RichTextEditor *customEditor)
 {
     auto lay = new QVBoxLayout(this);
     lay->setContentsMargins({});
+#ifdef HAVE_TEXT_TO_SPEECH_SUPPORT
     d->mTextToSpeechWidget = new KPIMTextEdit::TextToSpeechWidget(this);
     lay->addWidget(d->mTextToSpeechWidget);
+#endif
     if (customEditor) {
         d->mEditor = customEditor;
     } else {
         d->mEditor = new RichTextEditor;
     }
+#ifdef HAVE_TEXT_TO_SPEECH_SUPPORT
     connect(d->mEditor, &RichTextEditor::say, d->mTextToSpeechWidget, &KPIMTextEdit::TextToSpeechWidget::say);
+#endif
     lay->addWidget(d->mEditor);
 
     d->mSliderContainer = new KPIMTextEdit::SlideContainer(this);
