@@ -13,8 +13,12 @@
 #include <QLabel>
 #include <QPointer>
 #include <QSlider>
+#include <QTimer>
 #include <QToolButton>
 
+using namespace std::chrono_literals;
+#include <chrono>
+
 using namespace KPIMTextEdit;
 
 class Q_DECL_HIDDEN KPIMTextEdit::TextToSpeechWidgetPrivate
@@ -139,7 +143,7 @@ void TextToSpeechWidget::slotStateChanged(KPIMTextEdit::TextToSpeech::State stat
             if (d->mConfigDialog) {
                 d->mNeedToHide = true;
             } else {
-                hide();
+                QTimer::singleShot(2s, this, &TextToSpeechWidget::hide);
             }
         }
         break;
